==> sivel-1.0.6.tgz: htdocs/sivel/tablas_basicas.php <==
<?php 
// vim: set expandtab tabstop=4 shiftwidth=4 foldmethod=marker:

/**
* Tablas bsicas
 *
 * PHP version 5
 *
 * @category  SIVeL
 * @package   SIVeL
 * @author    Vladimir Tmara <vtamara@pasosdeJesus.org>
 * @copyright 2004 Dominio pblico. Sin garantas.
 * @license   http://creativecommons.org/licenses/publicdomain/ Dominio Pblico. Sin garantas.
 * @version   $Id: tablas_basicas.php,v 1.18 2009/05/03 12:23:21 vtamara Exp $
 * @link      http://sivel.sf.net
*/

/**
 * Presenta tablas bsicas
 */
require_once 'aut/aut.php';
require_once 'aut/conf.php';
require_once 'misc.php';

$aut_usuario = "";
autenticaUsuario($dsn, $accno, $aut_usuario, 11);

encabezado_envia("Tablas bsicas");

require_once 'HTML/Menu.php';
require_once 'HTML/Menu/DirectTreeRenderer.php';

$menu =& new HTML_Menu($GLOBALS['menu_tablas_basicas'], 'sitemap');
$rend =& new HTML_Menu_DirectTreeRenderer();
    
$rend->setEntryTemplate(HTML_MENU_ENTRY_INACTIVE, 
    '<a href = "tabla.php?tabla={url}">{title}</a>');
$menu->render($rend);
echo '<table border = "0" width = "100%"><tr>' .
    '<td style = "white-space: nowrap;background-color:#CCCCCC;" ' .
    'align="center" valign="top" colspan="2"><b>Tablas Bsicas</b>' .
    '</td></tr></table>';
print $rend->toHtml();

echo '<pr>&nbsp;</pr><table border="0" width="100%" ' .
    'style="white-space: nowrap; background-color:#CCCCCC;"><tr>' .
    '<td align="right">' .
    '<a href="index.php"><b>Men Principal</b></a>' .
    '</td></tr></table>';
    pie_envia();
?>

==> sivel-1.1.7p2.tgz: htdocs/sivel/tablas_basicas.php <==
<?php
// vim: set expandtab tabstop=4 shiftwidth=4 foldmethod=marker:

/**
* Tablas bsicas
 *
 * PHP version 5
 *
 * @category  SIVeL
 * @package   SIVeL
 * @author    Vladimir Tmara <vtamara@pasosdeJesus.org>
 * @copyright 2004 Dominio pblico. Sin garantas.
 * @license   https://www.pasosdejesus.org/dominio_publico_colombia.html DP
 *            Dominio Pblico. Sin garantas.
 * @version   CVS: $Revision: 1.26.2.1 $
 * @link      http://sivel.sf.net
*/

/**
 * Presenta tablas bsicas
 */
require_once 'aut.php';
require_once $_SESSION['dirsitio'] . '/conf.php';
require_once 'misc.php';
require_once 'misc_caso.php';

$aut_usuario = "";
autenticaUsuario($dsn, $accno, $aut_usuario, 11);

encabezado_envia("Tablas bsicas");

require_once 'HTML/Menu.php';
require_once 'HTML/Menu/DirectTreeRenderer.php';

actGlobales();

$menu =& new HTML_Menu($GLOBALS['menu_tablas_basicas'], 'sitemap');
$rend =& new HTML_Menu_DirectTreeRenderer();

$rend->setEntryTemplate(
    HTML_MENU_ENTRY_INACTIVE,
    '<a href = "tabla.php?tabla={url}">{title}</a>'
);
$menu->render($rend);
echo '<table border = "0" width = "100%"><tr>' .
    '<td style = "white-space: nowrap;background-color:#CCCCCC;" ' .
    'align="center" valign="top" colspan="2"><b>Tablas Bsicas</b>' .
    '</td></tr></table>';
print $rend->toHtml();

echo '<pr>&nbsp;</pr><table border="0" width="100%" ' .
    'style="white-space: nowrap; background-color:#CCCCCC;"><tr>' .
    '<td align="right">' .
    '<a href="index.php"><b>Men Principal</b></a>' .
    '</td></tr></table>';
    pie_envia();
?>
